vfbLib.parsers.truetype.TrueTypeZonesParser
===========================================

.. currentmodule:: vfbLib.parsers.truetype

.. autoclass:: TrueTypeZonesParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TrueTypeZonesParser.__init__
      ~TrueTypeZonesParser.parse
      ~TrueTypeZonesParser.parse_hex
      ~TrueTypeZonesParser.read_double
      ~TrueTypeZonesParser.read_doubles
      ~TrueTypeZonesParser.read_float
      ~TrueTypeZonesParser.read_floats
      ~TrueTypeZonesParser.read_int16
      ~TrueTypeZonesParser.read_int32
      ~TrueTypeZonesParser.read_int8
      ~TrueTypeZonesParser.read_str
      ~TrueTypeZonesParser.read_str_all
      ~TrueTypeZonesParser.read_uint16
      ~TrueTypeZonesParser.read_uint32
      ~TrueTypeZonesParser.read_uint8
      ~TrueTypeZonesParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TrueTypeZonesParser.encoding
      ~TrueTypeZonesParser.master_count
      ~TrueTypeZonesParser.stream
      ~TrueTypeZonesParser.ttStemsH_count
      ~TrueTypeZonesParser.ttStemsV_count
   
   